@@ -362,3 +362,79 @@ class MonteCarloAsianPut:
         else:
             inst_var = np.sqrt(sigma)
             self.price = self.simulate_price_svm(strike, n, S, mu, r, div, alpha, beta, rho, vol_var, inst_var, dt, T)
+
+
+class MonteCarloExtendibleCall:
+
+    def simulate_price_gbm(self, strike, n, r, S, mu, sigma, dt, T, extension):
+        payouts = []
+        for i in range(0, n):
+            GBM = GeometricBrownianMotion(S, mu, sigma, dt, T)
+            if(GBM.simulated_path[-1] >= strike):
+                payouts.append((GBM.simulated_path[-1] - strike)*np.exp(-r*T))
+            else:
+                GBM2 = GeometricBrownianMotion(GBM.simulated_path[-1], mu, sigma, dt, extension)  # Continue the simulation
+                if(GBM2.simulated_path[-1] >= strike):
+                    payouts.append((GBM2.simulated_path[-1] - strike)*np.exp(-r*T))
+                else:
+                    payouts.append(0)
+        return np.average(payouts)
+
+    def simulate_price_svm(self, strike, n, S, mu, r, div, alpha, beta, rho, vol_var, inst_var, dt, T, extension):
+        payouts = []
+        for i in range(0, n):
+            SVM = StochasticVarianceModel(S, mu, r, div, alpha, beta, rho, vol_var, inst_var, dt, T)
+            if(SVM.simulated_path[-1] >= strike):
+                payouts.append((SVM.simulated_path[-1] - strike)*np.exp(-r*T))
+            else:
+                SVM2 = StochasticVarianceModel(SVM.simulated_path[-1], mu, r, div, alpha, beta, rho, vol_var, inst_var, dt, T)  # Continue the simulation
+                if(SVM2.simulated_path[-1] >= strike):
+                    payouts.append((SVM2.simulated_path[-1] - strike)*np.exp(-r*T))
+                else:
+                    payouts.append(0)
+        return np.average(payouts)
+
+    def __init__(self, strike, n, r, S, mu, sigma, dt, T, extension, alpha=None, beta=None, rho=None, div=None, vol_var=None):
+        if alpha is None:
+            self.price = self.simulate_price_gbm(strike, n, r, S, mu, sigma, dt, T, extension)
+        else:
+            inst_var = np.sqrt(sigma)
+            self.price = self.simulate_price_svm(strike, n, S, mu, r, div, alpha, beta, rho, vol_var, inst_var, dt, T, extension)
+
+
+class MonteCarloExtendiblePut:
+
+    def simulate_price_gbm(self, strike, n, r, S, mu, sigma, dt, T, extension):
+        payouts = []
+        for i in range(0, n):
+            GBM = GeometricBrownianMotion(S, mu, sigma, dt, T)
+            if(GBM.simulated_path[-1] <= strike):
+                payouts.append((strike - GBM.simulated_path[-1])*np.exp(-r*T))
+            else:
+                GBM2 = GeometricBrownianMotion(GBM.simulated_path[-1], mu, sigma, dt, extension)  # Continue the simulation
+                if(GBM2.simulated_path[-1] <= strike):
+                    payouts.append((strike - GBM2.simulated_path[-1])*np.exp(-r*T))
+                else:
+                    payouts.append(0)
+        return np.average(payouts)
+
+    def simulate_price_svm(self, strike, n, S, mu, r, div, alpha, beta, rho, vol_var, inst_var, dt, T, extension):
+        payouts = []
+        for i in range(0, n):
+            SVM = StochasticVarianceModel(S, mu, r, div, alpha, beta, rho, vol_var, inst_var, dt, T)
+            if(SVM.simulated_path[-1] <= strike):
+                payouts.append((strike - SVM.simulated_path[-1])*np.exp(-r*T))
+            else:
+                SVM2 = StochasticVarianceModel(SVM.simulated_path[-1], mu, r, div, alpha, beta, rho, vol_var, inst_var, dt, T)  # Continue the simulation
+                if(SVM2.simulated_path[-1] <= strike):
+                    payouts.append((strike - SVM2.simulated_path[-1])*np.exp(-r*T))
+                else:
+                    payouts.append(0)
+        return np.average(payouts)
+
+    def __init__(self, strike, n, r, S, mu, sigma, dt, T, extension, alpha=None, beta=None, rho=None, div=None, vol_var=None):
+        if alpha is None:
+            self.price = self.simulate_price_gbm(strike, n, r, S, mu, sigma, dt, T, extension)
+        else:
+            inst_var = np.sqrt(sigma)
+            self.price = self.simulate_price_svm(strike, n, S, mu, r, div, alpha, beta, rho, vol_var, inst_var, dt, T, extension)
